@@ -15,5 +15,20 @@
 
 from pathlib import Path
 
-CURRENT_NS_PATH = Path(f"{Path.home()}/.current_ns")
-MSG_ANOTHER_NS_ACTIVE = "{name} namespace are active"
+USAGE = """
+punsctl <options>
+
+options:
+    -h                  Help menu
+    -r                  Root path                 (Default: ~/.ns)
+    -s                  Symlink path              (Default: ~/)
+    -l                  List namespaces
+    -n <namespace>      Create namespace
+    -d <namespace>      Delete namespace
+    -a <namespace>      Activate namespace
+    -x                  Deactivate namespaces
+"""
+
+DEFAULT_ROOT_PATH = f"{Path.home()}/.ns"
+DEFAULT_SYMLINK_PATH = f"{Path.home()}"
+CURRENT_NS_SYMLINK_NAME = ".current_ns"
